Wald_test reports Wald-type tests of linear contrasts from a fitted
linear regression model, using a sandwich estimator for the
variance-covariance matrix and a small sample correction for the p-value.
Several different small-sample corrections are available.
Wald_test(obj, constraints, vcov, test = "HTZ", ...)Fitted model for which to calculate Wald tests.
List of one or more constraints to test. See details below.
Variance covariance matrix estimated using vcovCR or a
character string specifying which small-sample adjustment should be used to
calculate the variance-covariance.
Character vector specifying which small-sample correction(s) to
calculate. The following corrections are available: "chi-sq",
"Naive-F", "HTA", "HTB", "HTZ", "EDF",
"EDT". Default is "HTZ".
Further arguments passed to vcovCR, which are only
needed if vcov is a character string.
A list of test results.
Constraints can be specified as character vectors, integer vectors, logical vectors, or matrices.