coef_test reports t-tests for each coefficient estimate in a fitted
linear regression model, using a sandwich estimator for the standard errors
and a small sample correction for the p-value. The small-sample correction is
based on a Satterthwaite approximation or a saddlepoint approximation.
coef_test(obj, vcov, test = "Satterthwaite", coefs = "All", ...)Fitted model for which to calculate t-tests.
Variance covariance matrix estimated using vcovCR or a
character string specifying which small-sample adjustment should be used to
calculate the variance-covariance.
Character vector specifying which small-sample corrections to
calculate. "z" returns a z test (i.e., using a standard normal
reference distribution). "naive-t" returns a t test with m -
1 degrees of freedom. "Satterthwaite" returns a Satterthwaite
correction. "saddlepoint" returns a saddlepoint correction. Default
is "Satterthwaite".
Character, integer, or logical vector specifying which
coefficients should be tested. The default value "All" will test all
estimated coefficients.
Further arguments passed to vcovCR, which are only
needed if vcov is a character string.
A data frame containing estimated regression coefficients, standard errors, and test results. For the Satterthwaite approximation, degrees of freedom and a p-value are reported. For the saddlepoint approximation, the saddlepoint and a p-value are reported.