| vcovCR.iv_robust | R Documentation |
estimatr::iv_robust object.vcovCR returns a sandwich estimate of the variance-covariance matrix
of a set of regression coefficient estimates from an
iv_robust object.
## S3 method for class 'iv_robust'
vcovCR(
obj,
cluster,
type,
target = NULL,
inverse_var = FALSE,
form = "sandwich",
...
)
obj |
Fitted model for which to calculate the variance-covariance matrix |
cluster |
Vector indicating which observations belong to
the same cluster. Required for |
type |
Character string specifying which small-sample adjustment should
be used, with available options |
target |
Optional matrix or vector describing the working
variance-covariance model used to calculate the |
inverse_var |
Not used for |
form |
Controls the form of the returned matrix. The default
|
... |
Additional arguments available for some classes of objects. |
An object of class c("vcovCR","clubSandwich"), which consists
of a matrix of the estimated variance of and covariances between the
regression coefficient estimates.
vcovCR
if (requireNamespace("estimatr", quietly = TRUE)) withAutoprint({
library(estimatr)
set.seed(20261201)
N <- 200
cluster <- factor(rep(1:20, each = 10))
z1 <- rnorm(N)
z2 <- rnorm(N)
x_exog <- rnorm(N)
x_endog <- 0.5 * z1 + 0.3 * z2 + rnorm(N)
y <- 1 + 2 * x_endog + 0.5 * x_exog + rnorm(N)
dat <- data.frame(y, x_endog, x_exog, z1, z2, cluster)
# Basic 2SLS with clusters and CR2
iv_fit <- iv_robust(
y ~ x_endog + x_exog | x_exog + z1 + z2,
data = dat,
clusters = cluster, se_type = "CR2"
)
vcovCR(iv_fit)
conf_int(iv_fit, vcov = "CR2")
# 2SLS with fixed effects
iv_fe <- iv_robust(
y ~ x_endog + x_exog | x_exog + z1 + z2,
fixed_effects = ~ cluster,
data = dat,
clusters = cluster,
se_type = "CR2"
)
vcovCR(iv_fe)
conf_int(iv_fe, vcov = "CR2")
})
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.