| vcovCR.lm_robust | R Documentation |
estimatr::lm_robust
object.vcovCR returns a sandwich estimate of the variance-covariance matrix
of a set of regression coefficient estimates from an
lm_robust object.
## S3 method for class 'lm_robust'
vcovCR(
obj,
cluster,
type,
target = NULL,
inverse_var = NULL,
form = "sandwich",
...
)
obj |
Fitted model for which to calculate the variance-covariance matrix |
cluster |
Expression or vector indicating which observations belong to
the same cluster. If not specified, will be detected from the
|
type |
Character string specifying which small-sample adjustment should
be used, with available options |
target |
Optional matrix or vector describing the working
variance-covariance model used to calculate the |
inverse_var |
Optional logical indicating whether the weights used in
fitting the model are inverse-variance. If not specified, |
form |
Controls the form of the returned matrix. The default
|
... |
Additional arguments available for some classes of objects. |
An object of class c("vcovCR","clubSandwich"), which consists
of a matrix of the estimated variance of and covariances between the
regression coefficient estimates.
vcovCR
data("ChickWeight", package = "datasets")
ChickWeight$Chick <- factor(ChickWeight$Chick, ordered = FALSE)
if (requireNamespace("estimatr", quietly = TRUE)) withAutoprint({
library(estimatr)
lm_fit <- lm_robust(
weight ~ Time + Diet:Time,
data = ChickWeight
)
vcovCR(lm_fit, cluster = ChickWeight$Chick, type = "CR2")
lm_fit_clust <- lm_robust(
weight ~ Time + Diet:Time, data = ChickWeight,
clusters = Chick
)
conf_int(lm_fit_clust, vcov = "CR2")
# similar model via lm_lin()
lin_fit_clust <- lm_lin(
weight ~ Diet,
covariates = ~ Time,
data = ChickWeight,
clusters = Chick
)
conf_int(lin_fit_clust, vcov = "CR2")
lm_fit_fe <- lm_robust(
weight ~ Time:Diet, data = ChickWeight,
clusters = Chick,
fixed_effects = ~ Chick
)
vcovCR(lm_fit_fe)
# two-way fixed effects model
data("MortalityRates")
MortalityRates <- subset(MortalityRates, cause == "Motor Vehicle")
MortalityRates$state <- factor(MortalityRates$state)
MortalityRates$year <- factor(MortalityRates$year)
MLDA_fit <- lm_robust(
mrate ~ legal + beertaxa + beerpercap + winepercap + spiritpercap,
fixed_effects = ~ year + state,
data = MortalityRates,
cluster = state
)
conf_int(MLDA_fit, vcov = "CR2")
if (requireNamespace("plm", quietly = TRUE)) withAutoprint({
data("Produc", package = "plm")
lm_individual <- lm_robust(
log(gsp) ~ log(pcap) + log(pc) + log(emp) + unemp,
data = Produc,
fixed_effects = ~ state,
cluster = state
)
vcovCR(lm_individual, type = "CR2")
})
})
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.