vcovCR.mmrm: Cluster-robust variance-covariance matrix for an mmrm object.

View source: R/mmrm.R

vcovCR.mmrmR Documentation

Cluster-robust variance-covariance matrix for an mmrm object.

Description

vcovCR returns a sandwich estimate of the variance-covariance matrix of a set of regression coefficient estimates from an mmrm object.

Usage

## S3 method for class 'mmrm'
vcovCR(obj, cluster, type, target, inverse_var, form = "sandwich", ...)

Arguments

obj

Fitted model for which to calculate the variance-covariance matrix

cluster

Optional expression or vector indicating which observations belong to the same cluster. If not specified, will be set to the subject variable from the mmrm model formula.

type

Character string specifying which small-sample adjustment should be used, with available options "CR0", "CR1", "CR1p", "CR1S", "CR2", or "CR3". See "Details" section of vcovCR for further information.

target

Optional matrix or vector describing the working variance-covariance model used to calculate the CR2 and CR4 adjustment matrices. If not specified, the target is taken to be the estimated variance-covariance structure of the mmrm object, with weights applied if present.

inverse_var

Optional logical indicating whether the weights used in fitting the model are inverse-variance. If not specified, vcovCR will attempt to infer a value.

form

Controls the form of the returned matrix. The default "sandwich" will return the sandwich variance-covariance matrix. Alternately, setting form = "meat" will return only the meat of the sandwich and setting form = B, where B is a matrix of appropriate dimension, will return the sandwich variance-covariance matrix calculated using B as the bread. form = "estfun" will return the (appropriately scaled) estimating function, the transposed crossproduct of which is equal to the sandwich variance-covariance matrix.

...

Additional arguments available for some classes of objects.

Value

An object of class c("vcovCR","clubSandwich"), which consists of a matrix of the estimated variance of and covariances between the regression coefficient estimates.

See Also

vcovCR

Examples


if (requireNamespace("mmrm", quietly = TRUE)) withAutoprint({

  library(mmrm)
  data(fev_data, package = "mmrm")

  # Fit an mmrm model with unstructured covariance
  mmrm_fit <- mmrm(
    FEV1 ~ RACE + SEX + ARMCD * AVISIT + us(AVISIT | USUBJID),
    data = fev_data
  )

  # CR2 cluster-robust variance estimator (cluster auto-detected)
  vcovCR(mmrm_fit, type = "CR2")

  # Coefficient tests with Satterthwaite degrees of freedom
  coef_test(mmrm_fit, vcov = "CR2", test = "Satterthwaite")

  # Fit a weighted mmrm model
  fev_data$wt <- 1 + rpois(nrow(fev_data), lambda = 3)
  mmrm_wt <- mmrm(
    FEV1 ~ RACE + SEX + ARMCD + us(AVISIT | USUBJID),
    data = fev_data,
    weights = fev_data$wt
  )

  # CR2 works with weighted models
  vcovCR(mmrm_wt, type = "CR2")

})


clubSandwich documentation built on May 4, 2026, 9:09 a.m.