| vcovCR.mmrm | R Documentation |
vcovCR returns a sandwich estimate of the variance-covariance matrix
of a set of regression coefficient estimates from an
mmrm object.
## S3 method for class 'mmrm'
vcovCR(obj, cluster, type, target, inverse_var, form = "sandwich", ...)
obj |
Fitted model for which to calculate the variance-covariance matrix |
cluster |
Optional expression or vector indicating which observations
belong to the same cluster. If not specified, will be set to the subject
variable from the |
type |
Character string specifying which small-sample adjustment should
be used, with available options |
target |
Optional matrix or vector describing the working
variance-covariance model used to calculate the |
inverse_var |
Optional logical indicating whether the weights used in
fitting the model are inverse-variance. If not specified, |
form |
Controls the form of the returned matrix. The default
|
... |
Additional arguments available for some classes of objects. |
An object of class c("vcovCR","clubSandwich"), which consists
of a matrix of the estimated variance of and covariances between the
regression coefficient estimates.
vcovCR
if (requireNamespace("mmrm", quietly = TRUE)) withAutoprint({
library(mmrm)
data(fev_data, package = "mmrm")
# Fit an mmrm model with unstructured covariance
mmrm_fit <- mmrm(
FEV1 ~ RACE + SEX + ARMCD * AVISIT + us(AVISIT | USUBJID),
data = fev_data
)
# CR2 cluster-robust variance estimator (cluster auto-detected)
vcovCR(mmrm_fit, type = "CR2")
# Coefficient tests with Satterthwaite degrees of freedom
coef_test(mmrm_fit, vcov = "CR2", test = "Satterthwaite")
# Fit a weighted mmrm model
fev_data$wt <- 1 + rpois(nrow(fev_data), lambda = 3)
mmrm_wt <- mmrm(
FEV1 ~ RACE + SEX + ARMCD + us(AVISIT | USUBJID),
data = fev_data,
weights = fev_data$wt
)
# CR2 works with weighted models
vcovCR(mmrm_wt, type = "CR2")
})
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.